@@ -12,13 +12,13 @@ from rich.text import Text
 from kopylot.audit import create_printtable_table, run_audit
 from kopylot.chat import run_chat
 from kopylot.diagnose import run_diagnose
+from kopylot.llm import validate_token
 from kopylot.utils import ai_print
+from kopylot.version import __version__
 
-app = typer.Typer()
+app = typer.Typer(no_args_is_help=True)
 console = Console()
 
-__version__ = "0.0.3"
-
 
 @app.command()
 def ctl(args: List[str]) -> subprocess.CompletedProcess:
@@ -103,10 +103,6 @@ def chat() -> None:
 
         with console.status("[bold green]Generting kubectl command..."):
             command = run_chat(user_prompt)
-            # command = (
-            #     "kubectl get pods -o jsonpath='{.items[].spec.containers[].image}' | tr -s '[[:space:]]' | sort | uniq"
-            #     " | wc -l"
-            # )
 
         rich.print(
             Panel(
@@ -126,7 +122,7 @@ def chat() -> None:
 
 def version_callback(value: bool) -> None:
     if value:
-        typer.echo(f"KoPylot Version: {__version__}")
+        typer.echo(f"KoPylot version: {__version__}")
         raise typer.Exit()
 
 
@@ -138,5 +134,15 @@ def common(
     pass
 
 
+def main() -> None:
+    if validate_token():
+        app()
+    else:
+        import sys
+
+        rich.print("[bold red]Error:[/bold red] KOPYLOT_AUTH_TOKEN not set.")
+        sys.exit(1)
+
+
 if __name__ == "__main__":
-    app()
+    main()
