@@ -5,6 +5,10 @@ import openai
 openai.api_key = os.getenv("KOPYLOT_AUTH_TOKEN", "")
 
 
+def validate_token() -> bool:
+    return openai.api_key != ""
+
+
 def ask_llm(prompt: str, temperature: float = 0.7, max_tokens: int = 2048) -> str:
     response = openai.Completion.create(
         engine="text-davinci-003",
